@@ -56,3 +56,9 @@ class Repository(metaclass=abc.ABCMeta):
 
     def __exit__(self, cls, exc, tb):
         self.teardown_context(cls, exc, tb)
+
+    async def __aenter__(self):
+        return self
+
+    async def __aexit__(self, cls, exc, tb):
+        pass
